@@ -1,5 +1,9 @@
 package org.gcube.portlets.widgets.wsmail.client;
 
+import java.util.ArrayList;
+import java.util.Date;
+import java.util.HashMap;
+
 import org.gcube.portlets.widgets.wsmail.client.forms.MailForm;
 
 import com.google.gwt.core.client.EntryPoint;
@@ -12,12 +16,18 @@ public class WsMail_Widget implements EntryPoint {
 	 * This is the entry point method.
 	 */
 	public void onModuleLoad() {
-		show();
+//		show();
 	}
 	/**
 	 * 
 	 */
 	public void show() {
-		new MailForm();
+		ArrayList<String> listContactsId = new ArrayList<String>();
+		listContactsId.add("massimiliano.assante");
+//		listContactsId.add("pino.pinetti");
+//		listContactsId.add("rino.gattuso");
+	
+
+		new MailForm(listContactsId);
 	}
 }
